import WPJSBase from "../Base/WPJSBase";
import PostDataType from "../Types/Data/PostDataType";
/**
 * Post class.
 *
 * @since 2.0.0
 */
export default class Post<T = PostDataType[] | PostDataType> extends WPJSBase<T> {
    private _slug;
    private _searchTerm;
    constructor(endpoint?: string);
    /**
     * Set the slug.
     * @param slug
     * @since 2.0.0
     * @description
     * This will set the slug. This is useful if you want to get posts from different slugs while keeping the same Post instance.
     * @example
     * import {Post} from "@quickdevelopment/wp-js";
     *
     * const slugPost = new Post();
     *
     * slugPost.bySlug('hello-world').fetch().then((post) => {
     *     // This will return the post from slug 'hello-world'.
     *     console.log(post)
     * })
     */
    bySlug(slug: string): this;
    /**
     * Get the slug.
     * @since 2.0.0
     */
    getSlug(): string;
    /**
     * Set the searchTerm.
     * @param searchTerm
     * @since 2.0.0
     * @description
     * This will set the searchTerm. This is useful if you want to get posts from different searchTerms while keeping the same Post instance.
     * @example
     * import {Post} from "@quickdevelopment/wp-js";
     *
     * const searchTermPosts = new Post();
     *
     * searchTermPosts.bySearchTerm('hello-world').fetch().then((posts) => {
     *     // This will return the post from search term 'hello-world'.
     *     console.log(posts)
     * })
     */
    bySearchTerm(searchTerm: string): this;
    /**
     * Get the searchTerm.
     * @since 2.0.0
     */
    getSearchTerm(): string;
    /**
     * Set the author.
     * @param userId
     * @since 2.0.0
     * @description
     * This will set the author. This is useful if you want to get posts from different authors while keeping the same Post instance.
     * @example
     * import {Post} from "@quickdevelopment/wp-js";
     *
     * const authorPosts = new Post();
     *
     * authorPosts.byAuthor(1).fetch().then((posts) => {
     *     // This will return the posts from author with id 1.
     *     console.log(posts)
     * })
     */
    byAuthor(userId: number): this;
    /**
     * Set the amount of posts to take.
     * @param perPage
     * @param page
     * @since 2.0.0
     * @description
     * This will paginate the posts using per_page and the page query parameters.
     */
    paginate(perPage: number, page: number): this;
    /**
     * Get a single post.
     * @since 2.0.0
     * @example
     * import {Post} from "@quickdevelopment/wp-js";
     *
     * const post = new Post('posts/1');
     *
     * post.fetch().then((post) => {
     *     console.log(post)
     * })
     */
    fetch(): Promise<T | T[]>;
}
